==> flutter_platform_component-1.0.1.tar.gz: example/lib/presentation/component_list/component_list_wdget.dart <==
import 'package:flutter_platform_component/flutter_platform_component.dart';
import 'package:example/service/navigation_service.dart';
import 'package:flutter/material.dart';

class ComponentListWidget extends StatelessWidget {
  const ComponentListWidget({Key? key});

  @override
  Widget build(BuildContext context) {
    final FPCConfig config = FPCConfig.of(context);
    final IFPCSize size = config.size;

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.min,
      children: [
        FPCPrimaryButton(
          title: "Animated Container",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.animated_container_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Cross Fade",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.animated_cross_fade_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Fade In",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.animated_fade_in_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Fade Out",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.animated_fade_out_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Opacity Stack",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_opacity_stack_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Opacity",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.animated_opacity_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Switcher",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.animated_switcher_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Transition Switcher",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_transition_switcher_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "App Bar",
          onPressed: () => Navigator.pushNamed(context, NavigationService.app_bar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur App Bar",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.blur_app_bar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Counter Badge",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.counter_badge_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Counter Badge",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_counter_badge_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Dot Badge",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.dot_badge_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Dot Badge",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_dot_badge_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Blur",
          onPressed: () => Navigator.pushNamed(context, NavigationService.blur_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Button",
          onPressed: () => Navigator.pushNamed(context, NavigationService.button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Button",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Icon Button",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.icon_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Modal Button",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.modal_button_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Card",
          onPressed: () => Navigator.pushNamed(context, NavigationService.card_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Card",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_card_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Select Card",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.select_card_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Select Card",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_select_card_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Checkbox",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.checkbox_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Code Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.code_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Code Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_code_field_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Dialog",
          onPressed: () => Navigator.pushNamed(context, NavigationService.dialog_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Divider",
          onPressed: () => Navigator.pushNamed(context, NavigationService.divider_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Form Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.form_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Form Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_form_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Select Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.select_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Select Field",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_select_field_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Gradient",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Icon",
          onPressed: () => Navigator.pushNamed(context, NavigationService.icon_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Circular Indicator",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.circular_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Page Indicator",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.page_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Page Indicator",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_page_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Progress Indicator",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.progress_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Story Indicator",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.story_indicator_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Keyboard Button",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.keyboard_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Keyboard Number Button",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.keyboard_number_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Keyboard",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.keyboard_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "List Refresh",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.list_refresh_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "List Section",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.list_section_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Action Modal",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.action_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Expanded Modal",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.expanded_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Black Always Expanded Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.black_always_expand_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur Expanded Modal",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.blur_expanded_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur Black Always Expanded Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.blur_black_always_expand_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Pop Up Modal",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.pop_up_modal_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Bottom Navigation Bar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.bottom_navigation_bar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur Bottom Navigation Bar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.blur_bottom_navigation_bar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Navigator",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.navigator_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Date Picker",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.date_picker_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Time Picker",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.time_picker_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "PIN Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.pin_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient PIN Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_pin_field_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Radio",
          onPressed: () => Navigator.pushNamed(context, NavigationService.radio_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Scaffold",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.scaffold_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Scrollbar",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.scrollbar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Segment Control",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.segment_control_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Segment Control",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_segment_control_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Shimmer",
          onPressed: () => Navigator.pushNamed(context, NavigationService.shimmer_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Shimmer",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_shimmer_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Slider",
          onPressed: () => Navigator.pushNamed(context, NavigationService.slider_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Sliding Segment Control",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.sliding_segment_control_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Sliver Navigation Bar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.sliver_navigation_bar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Snackbar",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.snackbar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Snackbar",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_snackbar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Switch",
          onPressed: () => Navigator.pushNamed(context, NavigationService.switch_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Text",
          onPressed: () => Navigator.pushNamed(context, NavigationService.text_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Text Span",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.text_span_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Toggle",
          onPressed: () => Navigator.pushNamed(context, NavigationService.toggle_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Toggle",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_toggle_screen),
        ),
      ],
    );
  }
}

==> flutter_platform_component-1.0.3.tar.gz: example/lib/presentation/component_list/component_list_wdget.dart <==
import 'package:flutter_platform_component/flutter_platform_component.dart';
import 'package:example/service/navigation_service.dart';
import 'package:flutter/material.dart';

class ComponentListWidget extends StatelessWidget {
  const ComponentListWidget({Key? key});

  @override
  Widget build(BuildContext context) {
    final FPCConfig config = FPCConfig.of(context);
    final IFPCSize size = config.size;

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.min,
      children: [
        FPCPrimaryButton(
          title: "Animated Container",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_container_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Cross Fade",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_cross_fade_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Fade In",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_fade_in_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Fade Out",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_fade_out_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Opacity Stack",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_opacity_stack_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Opacity",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_opacity_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Switcher",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_switcher_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Animated Transition Switcher",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.animated_transition_switcher_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "App Bar",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.app_bar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur App Bar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.blur_app_bar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Counter Badge",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.counter_badge_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Counter Badge",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_counter_badge_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Dot Badge",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.dot_badge_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Dot Badge",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_dot_badge_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Blur",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.blur_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Button",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Button",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Icon Button",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.icon_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Modal Button",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.modal_button_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Card",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.card_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Card",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_card_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Select Card",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.select_card_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Select Card",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_select_card_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Checkbox",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.checkbox_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Code Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.code_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Code Field",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_code_field_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Dialog",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.dialog_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Divider",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.divider_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Form Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.form_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Form Field",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_form_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Select Field",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.select_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Select Field",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_select_field_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Gradient",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.gradient_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Icon",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.icon_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Circular Indicator",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.circular_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Page Indicator",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.page_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Page Indicator",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_page_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Progress Indicator",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.progress_indicator_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Story Indicator",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.story_indicator_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Keyboard Button",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.keyboard_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Keyboard Number Button",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.keyboard_number_button_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Keyboard",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.keyboard_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "List Refresh",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.list_refresh_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "List Section",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.list_section_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Action Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.action_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Expanded Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.expanded_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Black Always Expanded Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.black_always_expand_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur Expanded Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.blur_expanded_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur Black Always Expanded Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.blur_black_always_expand_modal_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Pop Up Modal",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.pop_up_modal_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Bottom Navigation Bar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.bottom_navigation_bar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Blur Bottom Navigation Bar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.blur_bottom_navigation_bar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Navigator",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.navigator_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Date Picker",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.date_picker_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Time Picker",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.time_picker_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "PIN Field",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.pin_field_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient PIN Field",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_pin_field_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Radio",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.radio_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Scaffold",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.scaffold_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Scrollbar",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.scrollbar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Segment Control",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.segment_control_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Segment Control",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_segment_control_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Shimmer",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.shimmer_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Shimmer",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_shimmer_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Slider",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.slider_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Sliding Segment Control",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.sliding_segment_control_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Sliver Navigation Bar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.sliver_navigation_bar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Snackbar",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.snackbar_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Snackbar",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_snackbar_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Switch",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.switch_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Text",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.text_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Text Span",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.text_span_screen),
        ),
        SizedBox(height: size.s16),
        FPCPrimaryButton(
          title: "Toggle",
          onPressed: () =>
              Navigator.pushNamed(context, NavigationService.toggle_screen),
        ),
        SizedBox(height: size.s16 / 2),
        FPCPrimaryButton(
          title: "Gradient Toggle",
          onPressed: () => Navigator.pushNamed(
              context, NavigationService.gradient_toggle_screen),
        ),
      ],
    );
  }
}
